# lholipop
![CI](https://github.com/grburgess/lholipop/workflows/CI/badge.svg?branch=master)
[![codecov](https://codecov.io/gh/grburgess/lholipop/branch/master/graph/badge.svg)](https://codecov.io/gh/grburgess/lholipop)
[![Documentation Status](https://readthedocs.org/projects/lholipop/badge/?version=latest)](https://lholipop.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3372456.svg)](https://doi.org/10.5281/zenodo.3372456)
![PyPI](https://img.shields.io/pypi/v/lholipop)
![PyPI - Downloads](https://img.shields.io/pypi/dm/lholipop)

![alt text](https://raw.githubusercontent.com/grburgess/lholipop/master/docs/media/logo.png)

The **Lepto-Hadronic ObservationaL Intrinsic Population** synthesis framework allows for
multimessenger data from photons, neutrinos, and cosmic-rays to be generated by
folding the multi-species output of the [SOPRANO]() radiative code through
various instrument responses (e.g. photometric optical telescopes, x-ray
telescaopes, Fermi-LAT, IceCube). The intrinsic inputs for each observations are
sampled from an input cosmological population using [popsynth](), then fed to
SOPRANO resulting in fluxes of various species which can then be converted to
data via instrument responses and selection effects applied.

The modeling and reconstruction of both spectra and observations use a
combination of neural networks for speed. Datasets can be analyzed with 3ML to
produce reduced observables or combined in a high-level analysis to assess
association properties.

* Free software: GNU General Public License v3
* Documentation: https://lholipop.readthedocs.io.


## Features


* TODO

## Credits

